/* Copyright (c) 2008, Sheng Guo, Li-San Wang and Junhyong Kim, University of
  Pennsylvania.  All Rights Reserved.
 
  You may not use this file except in compliance with the License
  located in the top directory of this distribution.  You may obtain
  a copy of the License at
 
      http://kim.bio.upenn.edu/software/index.shtml
 
  Unless required by applicable law or agreed to in writing, this
  software is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
  CONDITIONS OF ANY KIND, either express or implied.  See the License
  for the specific language governing permissions and limitations
  under the License. 
*/


/*******************************************************************************************
	Description:Numerical representation of RNA sequence and its pairing information.
				It also provides functions for retrieving and printing sequence and 
				base pairing information.
				Generated by class RNAWithPairingParser.
				--Numerical representation of nucleotides	
					A/a	0
					U/u	1
					C/c	2
					G/g	3
				--Numerical representation of base pairings
					unpaired: -1
					paired: the index of its paired nucleotide
				--example RNA in parenthesis format
					GGGGGATTAGCTCAAGCGGTAGGGTGCCTGCTTAGCATGCAAGAGGtAGCAGGATCGACGCCTGCATTCTCCA
					(((((((..((((........)))).(.(((.......))).).....(((((.......)))))))))))).				
********************************************************************************************/
#ifndef RNAWITHPAIRING_H
#define RNAWITHPAIRING_H

#include <string>
#include <vector>
#include <iostream>
#include <sstream>


using namespace std;

class RNAWithPairing{
public:
	RNAWithPairing();	//default constructor
	RNAWithPairing(const RNAWithPairing & r);	//copy constructor
	RNAWithPairing(const vector<int> &, const vector<int> &);	//copy constructor
	
	string getPairingStr(int width = 0) const;		
	string getSeqStr(int width = 0) const;

	string repr(int rule=0, int rowwidth_in_tens = 6) const;
	string terserepr() const;
	string verboserepr() const;
	
	string format(int) const;
	
	void assignW(double gamma_shape, double gamma_rate, double maxweight);
	void assignC();

	vector<int> * getS();
	vector<int> * getP();
	vector<double> * getW();
	vector<string> * getC();

private:
	vector<int> s;	//numerical representation of sequence, see translation table above
	vector<int> p;	//base pairing; ..((..)) is -1 -1 8 7 -1 -1 3 4;
	vector<double> w;	//weight associated with the base
	vector<string> c;	//unique sequence identifier for each site: each site has a unique number derived from its parent
};

#endif
//END_OF_FILE
