/* Copyright (c) 2008, Sheng Guo, Li-San Wang and Junhyong Kim, University of
  Pennsylvania.  All Rights Reserved.
 
  You may not use this file except in compliance with the License
  located in the top directory of this distribution.  You may obtain
  a copy of the License at
 
      http://kim.bio.upenn.edu/software/index.shtml
 
  Unless required by applicable law or agreed to in writing, this
  software is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
  CONDITIONS OF ANY KIND, either express or implied.  See the License
  for the specific language governing permissions and limitations
  under the License. 
*/

#include "RNAWithPairingParser.h"

using namespace std;

/* parse rna sequence and rna pairing to return a pointer to an RNAWithPairing object */
RNAWithPairing * RNAWithPairingParser::parse(const string & seq, const string & bp){

	int seqlen = seq.size();
	vector<int> numseq(seqlen);
	vector<int> pairing(seqlen, -1);	//unpaired base is assigned -1;
	
	int i = 0;
	//get numerical representation of sequence
	for(i=0; i<seqlen; i++){
		switch(seq[i]){
			case 'A': numseq[i] = 0; break;
			case 'a': numseq[i] = 0; break;
			case 'U': numseq[i] = 1; break;
			case 'u': numseq[i] = 1; break;
			case 'C': numseq[i] = 2; break;
			case 'c': numseq[i] = 2; break;
			case 'G': numseq[i] = 3; break;
			case 'g': numseq[i] = 3; break;
			default: cerr<<"Fatal error at file "<<__FILE__<<" line "<<__LINE__
						 <<" : Unrecognized nucleotide name "<<seq[i]<<endl; 
					exit(1);
		}
	}	

	//compute the pairing vector
	i = 0;
	stack<int> stack;
	
	while(i<seqlen){
		if( bp[i] == '<' || bp[i] == '(')
			stack.push(i);
		if( bp[i] == '>' || bp[i] == ')'){
			int x = stack.top();
			stack.pop();
			pairing[x] = i;
			pairing[i] = x;
		}
		i++;
	}
	
	//RNAWithPairing * r = new RNAWithPairing(numseq, pairing);	
	//return r;
	return new RNAWithPairing(numseq, pairing);	
}
//END_OF_FILE
