/* Copyright (c) 2008, Sheng Guo, Li-San Wang and Junhyong Kim, University of
  Pennsylvania.  All Rights Reserved.
 
  You may not use this file except in compliance with the License
  located in the top directory of this distribution.  You may obtain
  a copy of the License at
 
      http://kim.bio.upenn.edu/software/index.shtml
 
  Unless required by applicable law or agreed to in writing, this
  software is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
  CONDITIONS OF ANY KIND, either express or implied.  See the License
  for the specific language governing permissions and limitations
  under the License. 
*/

 /*******************************************************************************************
	Parse a RNA sequence and its corresponding pairing sequence in VIENNA
	format, and return pointer to a RNAWithPairing object, the sequence and
	base-paring is represented in number.
	--Numerical representation of nucleotides	
			A/a	0
			U/u	1
			C/c	2
			G/g	3
	--Numerical representation of base pairings
			unpaired: -1
			paired: the index of its paired nucleotide	
********************************************************************************************/

#ifndef RNAWITHPAIRINGPARSER_H
#define RNAWITHPAIRINGPARSER_H

#include "RNAWithPairing.h"

#include <iostream>
#include <string>
#include <vector>
#include <stack>

using namespace std;

class RNAWithPairingParser{
        /*seq is the RNA sequence, and bp is the base pairing sequence.
           Example:
           Seq: GGGGGATTAGCTCAAGCGGTAGGGTGCCTGCTTAGCATGCAAGAGGtAGCAGGATCGACGCCTGCATTCTCCA 
           Str: (((((((..((((........)))).(.(((.......))).).....(((((.......)))))))))))). 
                ) and >, ( and < can be interchangeably used."""
		   return numerical representation of seq and pairing */

public:
	RNAWithPairing * parse(const string & seq, const string & bp);
	
};

#endif
//END_OF_FILE
